@@ -6,8 +6,8 @@ from copy import deepcopy
 sys.path.append('./')  # to run '$ python *.py' files in subdirectories
 logger = logging.getLogger(__name__)
 import torch
-from models.common import *
-from models.experimental import *
+from yolov7_package.models.common import *
+from yolov7_package.models.experimental import *
 from yolov7_package.utils import check_anchor_order
 from yolov7_package.utils import make_divisible, check_file, set_logging
 from yolov7_package.utils import time_synchronized, fuse_conv_and_bn, model_info, scale_img, initialize_weights, \
